<?php

/**
 * WHMCS Paysepro Module
 * Version: 1.1
 * Date : 	2021-04-26
 *
 */

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}

/**
 * Define module related meta data.
 *
 * @return array
 */
function paysepro_MetaData()
{
    return array(
        'DisplayName' => 'Checkout Paysepro',
        'APIVersion' => '1.1', // Use API Version 1.1
        'DisableLocalCredtCardInput' => true,
        'TokenisedStorage' => false,
    );
}

/**
 * Define gateway configuration options.
 *
 * @return array
 */
function paysepro_config()
{
    return array(
        'FriendlyName' => array(
            'Type' => 'System',
            'Value' => 'Paysepro',
        ),
        'APIUId' => array(
            'FriendlyName' => 'API UID',
            'Type' => 'text',
            'Size' => '250',
            'Default' => '',
            'Description' => 'Enter your UID',
        ),
        'APIMId' => array(
            'FriendlyName' => 'API MID',
            'Type' => 'text',
            'Size' => '250',
            'Default' => '',
            'Description' => 'Enter your MID',
		),
		'APIColor' => array(
			'FriendlyName' => 'Color',
			'Type' => 'dropdown',
				'Options' => 'white,green,black',
			'Description' => '(white,green,black)',
			'Default' => 'white',
		),
        'APILocalPrice' => array(
			'FriendlyName' => 'Store logo URL',
			'Type' => 'text',
			'Size' => '128',
			'Default' => '',
			'Description' => 'Enter your store logo URL',
		),
        'APISupportEmail' => array(
			'FriendlyName' => 'Store Support',
			'Type' => 'text',
			'Size' => '250',
			'Default' => '',
			'Description' => 'Email or contact phone number of your store.',
        ),
        'APICommerceName' => array(
			'FriendlyName' => 'Store Name',
			'Type' => 'text',
			'Size' => '250',
			'Default' => '',
			'Description' => 'Enter your store name',
		),
        'APIPName' => array(
			'FriendlyName' => 'Product Name',
			'Type' => 'text',
			'Size' => '128',
			'Default' => '',
			'Description' => 'Product name',
        ),

        'APIDescription' => array(
			'FriendlyName' => 'Product Description',
			'Type' => 'text',
			'Size' => '250',
			'Default' => '',
			'Description' => 'Product description',
        ),

    );
}

function paysepro_link($params)
{
	$fname=basename($_SERVER["SCRIPT_FILENAME"], '.php');
	if($fname=="cart") return("");
    // Gateway Configuration Parameters
    $APIUId			= $params['APIUId'];
    $APIMId 		= $params['APIMId'];
    $APIColor 		= $params['APIColor'];
    $APILocalPrice 	= urlencode($params['APILocalPrice']);

	$APISupportEmail= urlencode($params['APISupportEmail']);
	$APICommerceName= urlencode($params['APICommerceName']);
	$APIDescription	= urlencode($params['APIDescription']);
	$APIPName		= urlencode($params['APIPName']);

    // Invoice Parameters
	$invoiceId		= $params['invoiceid'];
    $description 	= $params["description"];
    $amount 		= $params['amount'];
    $currencyCode 	= $params['currency'];	# Currency Code

    // Client Parameters
	$firstname	= $params['clientdetails']['firstname'];
    $lastname 	= $params['clientdetails']['lastname'];
    $email 		= $params['clientdetails']['email'];
	$phone 		= $params['clientdetails']['phonenumber'];
    $address1 	= $params['clientdetails']['address1'];
    $city 		= $params['clientdetails']['city'];
    $state 		= $params['clientdetails']['state'];
    $postcode 	= $params['clientdetails']['postcode'];
    $country 	= $params['clientdetails']['country'];

    // System Parameters
    $companyName		= $params['companyname'];
    $systemUrl 			= $params['systemurl'];
    $returnUrl 			= $params['returnurl'];
    $langPayNow 		= $params['langpaynow'];
    $moduleDisplayName 	= $params['name'];
    $moduleName 		= $params['paymentmethod'];
    $whmcsVersion 		= $params['whmcsVersion'];

	// Paysepro api base url
	$psp_api_base_url = "https://checkout.paysepro.com/";

	# Paysepro supported currency lists
	$psp_euro_factor = array(
		"default" => 1,
		"eur" => 1,
		"usd" => 1,
		"gbp" => 1,
	);

	// Paysepro supported colorbox colors
	$psp_colorbox_colors = array("white","green","black");

	if(isset($psp_euro_factor[strtolower($currencyCode)]))
	{
		$price = ($amount * $psp_euro_factor[strtolower($currencyCode)]);
	} else {
		$price = ($amount * $psp_euro_factor["default"]);
	}
	$price = number_format($price, 2);

	$ucode = $invoiceId;

	$uid = intval($APIUId);
	$mid = intval($APIMId);
	$ac = in_array($APIColor, $psp_colorbox_colors) ? $APIColor : "white"; // default red color

	$url = $psp_api_base_url . "?uid=$uid&mid=$mid&ucode=$ucode&price=$price&store=$APICommerceName&description=$APIDescription&contact=$APISupportEmail&product=$APIPName&logo=$APILocalPrice";
	$url_button = $psp_api_base_url . "/image.php?uid=$uid&mid=$mid&color=$ac";

	if(1)
	{
		$htmlOutput = '
<a href="'.$url.'" title="Pagar" target="_blank"><img src="'.$url_button.'" alt="pay" /></a>';
	} else {
		$htmlOutput = '<link rel="stylesheet" href="'.$psp_api_base_url.'/css/psp-lightbox.css" />
<script src="'.$psp_api_base_url.'/js/psp-lightbox.js"></script>
<script>
   window.onload = function() {
      [].forEach.call(document.querySelectorAll(\'[psp-lightbox]\'), function(el) {
         el.lightbox = new EpLightbox(el);
      });
   };
</script>
<a href="'.$url.'" psp-lightbox="iframe" url="'.$url.'" title="Pagar"><img src="'.$url_button.'" alt="pay" /></a>';
	}

	return $htmlOutput;
}
